package de.intevation.flys.client.client.ui;

import java.io.Serializable;

import com.smartgwt.client.widgets.Canvas;

import de.intevation.flys.client.shared.model.DataList;


/**
 * This interface describes a method that creates a Canvas element displaying
 * DataItems for a current state of the artifact.
 *
 * @author <a href="mailto:ingo.weinzierl@intevation.de">Ingo Weinzierl</a>
 */
public interface UIProvider extends Serializable {

    /**
     * This method creates a Canvas element showing the DataItems in
     * <i>data</i>.
     *
     * @param data The DataList object.
     *
     * @return the Canvas showing the Data.
     */
    public Canvas create(DataList data);


    /**
     * This method creates a Canvas element showing the old Data objects in the
     * DataList <i>data</i>.
     *
     * @param dataList The DataList which elements should be displayed.
     *
     * @return a Canvas displaying the Data.
     */
    public Canvas createOld(DataList dataList);


    /**
     * This method injects a container that is used to position helper widgets.
     *
     * @param container A container that is used to position helper widgets.
     */
    public void setContainer(Canvas container);
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
